@@ -13,7 +13,7 @@
 #' - `treeshap::treeshap()`,
 #' - `DALEX::predict_parts()`,
 #' - `kernelshap::kernelshap()`, and
-#' - `permshap::permshap()`,
+#' - `kernelshap::permshap()`,
 #'
 #' check the vignettes for examples.
 #'
@@ -111,10 +111,9 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #'   Creates a "shapviz" object from an XGBoost model.
 #' @export
 #' @examples
-#' \dontrun{
 #' # XGBoost models
 #' X_pred <- data.matrix(iris[, -1])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = iris[, 1])
+#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = iris[, 1], nthread = 1)
 #' fit <- xgboost::xgb.train(data = dtrain, nrounds = 10, nthread = 1)
 #'
 #' # Will use numeric matrix "X_pred" as feature matrix
@@ -132,8 +131,10 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #' # Multiclass setting
 #' params <- list(objective = "multi:softprob", num_class = 3)
 #' X_pred <- data.matrix(iris[, -5])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 5]) - 1)
-#' fit <- xgboost::xgb.train(params = params, data = dtrain, nrounds = 10)
+#' dtrain <- xgboost::xgb.DMatrix(
+#'   X_pred, label = as.integer(iris[, 5]) - 1, nthread = 1
+#' )
+#' fit <- xgboost::xgb.train(params = params, data = dtrain, nrounds = 10, nthread = 1)
 #'
 #' # Select specific class
 #' x <- shapviz(fit, X_pred = X_pred, which_class = 3)
@@ -145,7 +146,7 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #'
 #' # What if we would have one-hot-encoded values and want to explain the original column?
 #' X_pred <- stats::model.matrix(~ . -1, iris[, -1])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 1]))
+#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 1]), nthread = 1)
 #' fit <- xgboost::xgb.train(data = dtrain, nrounds = 10, nthread = 1)
 #' x <- shapviz(
 #'   fit,
@@ -182,7 +183,6 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #'   mx
 #'   all.equal(mx[[3]], x)
 #' }
-#' }
 shapviz.xgb.Booster = function(object, X_pred, X = X_pred, which_class = NULL,
                                collapse = NULL, interactions = FALSE, ...) {
   stopifnot(
@@ -413,7 +413,7 @@ shapviz.kernelshap <- function(object, X = object[["X"]],
 }
 
 #' @describeIn shapviz
-#'   Creates a "shapviz" object from `permshap::permshap()`.
+#'   Creates a "shapviz" object from `kernelshap::permshap()`.
 #' @export
 shapviz.permshap <- function(object, X = object[["X"]],
                              which_class = NULL, collapse = NULL, ...) {
@@ -462,9 +462,9 @@ shapviz.H2OModel = function(object, X_pred, X = as.data.frame(X_pred),
   )
 }
 
-#' Concatenates "shapviz" Objects
+#' Combines compatible "shapviz" Objects
 #'
-#' This function combines a list of "shapviz" objects to an object of class
+#' This function combines a list of compatible "shapviz" objects to an object of class
 #' "mshapviz". The elements can be named.
 #'
 #' @param object List of "shapviz" objects to be concatenated.
@@ -479,10 +479,21 @@ shapviz.H2OModel = function(object, X_pred, X = as.data.frame(X_pred),
 #' s <- mshapviz(c(shp1 = s1, shp2 = s2))
 #' s
 mshapviz <- function(object, ...) {
-  stopifnot("'object' must be a list of 'shapviz' objects" = is.list(object))
+  stopifnot("'object' must be a list" = is.list(object))
   if (!all(vapply(object, is.shapviz, FUN.VALUE = logical(1)))) {
     stop("Must pass list of 'shapviz' objects")
   }
+  nms <- lapply(object, colnames)
+  if (!all(vapply(nms, identical, y = nms[[1L]], FUN.VALUE = logical(1)))) {
+    stop("'shapviz' objects need to have identical column names")
+  }
+  # Plot methods using interactions and do.call(rbind, ...) will fail, other plots are ok
+  # inter <- vapply(
+  #   object, function(x) is.null(get_shap_interactions(x)), FUN.VALUE = logical(1)
+  # )
+  # if (!(all(inter) || !any(inter))) {
+  #   stop("Some 'shapviz' objects have SHAP interactions, some not.")
+  # }
   structure(object, class = "mshapviz")
 }
 
