@@ -11,6 +11,10 @@ test_that("get_* functions work", {
   expect_equal(4, get_baseline(mshp)[[1L]])
   expect_equal(S, get_shap_values(mshp)[[1L]])
   expect_equal(X, get_feature_values(mshp)[[1L]])
+
+  expect_error(get_baseline(3))
+  expect_error(get_shap_values("a"))
+  expect_error(get_feature_values(c(3, 9)))
 })
 
 test_that("dim, nrow, ncol, colnames work", {
@@ -51,6 +55,17 @@ test_that("concatenating with + works", {
   expect_equal((shp + shp)$baseline, shp$baseline)
   expect_equal(dim((shp + shp + shp)$S), c(6L, 2L))
   expect_equal(dim((shp + shp + shp)$X), c(6L, 2L))
+
+  # mshapviz
+  mapply(function(x, dims) {
+    expect_equal(dim(x$S), dims)
+    expect_equal(dim(x$X), dims)
+  }, x = mshp + mshp, dims = list(c(4L, 2L), c(8L, 2L)))
+  mapply(function(x, x_sum) expect_equal(x$baseline, x_sum$baseline), x = mshp, x_sum = mshp + mshp)
+  mapply(function(x, dims) {
+    expect_equal(dim(x$S), dims)
+    expect_equal(dim(x$X), dims)
+  }, x = mshp + mshp + mshp, dims = list(c(6L, 2L), c(12L, 2L)))
 })
 
 test_that("concatenating with rbind works", {
@@ -59,6 +74,18 @@ test_that("concatenating with rbind works", {
   expect_equal(rbind(shp, shp)$baseline, shp$baseline)
   expect_equal(dim(rbind(shp, shp, shp)$S), c(6L, 2L))
   expect_equal(dim(rbind(shp, shp, shp)$X), c(6L, 2L))
+
+  # mshapviz
+  mshp_rbind <- rbind(mshp, mshp)
+  expect_equal(dim(mshp_rbind$shp$S), c(4L, 2L))
+  expect_equal(dim(mshp_rbind$shp2$S), c(8L, 2L))
+  expect_equal(dim(mshp_rbind$shp$X), c(4L, 2L))
+  expect_equal(dim(mshp_rbind$shp2$X), c(8L, 2L))
+  mapply(function(x, xbind) expect_equal(x$baseline, xbind$baseline), x = mshp, xbind = mshp_rbind)
+  mapply(function(x, dims) {
+    expect_equal(dim(x$S), dims)
+    expect_equal(dim(x$X), dims)
+  }, x = rbind(mshp, mshp, mshp), dims = list(c(6L, 2L), c(12L, 2L)))
 })
 
 test_that("split() works", {
@@ -176,6 +203,8 @@ mshp_inter <- c(shp1 = shp_inter, shp2 = shp_inter + shp_inter)
 
 test_that("get_shap_interactions, +, rbind works for interactions", {
   expect_equal(S_inter, get_shap_interactions(shp_inter))
+  expect_equal(length(get_shap_interactions(mshp_inter)), 2L)
+  expect_error(get_shap_interactions(4))
   expect_equal(dim((shp_inter + shp_inter)$S_inter)[1L], 2 * dim(shp_inter$S_inter)[1L])
   expect_equal(
     dim(rbind(shp_inter, shp_inter, shp_inter)$S_inter)[1L],
@@ -211,39 +240,51 @@ test_that("mshapviz object contains original shapviz objects", {
   expect_equal(mshp_inter[[2L]][1:nrow(shp_inter)], shp_inter)
 })
 
-# # Multiclass with XGBoost
-# X_pred <- data.matrix(iris[, -5L])
-# dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 5L]) - 1L)
-# fit <- xgboost::xgb.train(
-#   params = list(nthread = 1L),
-#   data = dtrain,
-#   nrounds = 1L,
-#   objective="multi:softprob",
-#   num_class = 3L
-# )
-# shp3 <- shapviz(fit, X_pred = X_pred, which_class = 3L, interactions = TRUE)
-# mshp <- shapviz(fit, X_pred = X_pred, interactions = TRUE)
-#
-# test_that("is.shapviz() and is.mshapviz() functions work", {
-#   expect_true(is.shapviz(shp3))
-#   expect_true(is.mshapviz(mshp))
-#   expect_false(is.shapviz(mshp))
-#   expect_false(is.mshapviz(shp3))
-# })
-#
-# test_that("shapviz on class 3 equals mshapviz[[3]] for classification", {
-#   expect_equal(mshp[[3L]], shp3)
-# })
-#
-# test_that("combining shapviz on classes 1, 2, 3 equal mshapviz", {
-#   shp1 <- shapviz(fit, X_pred = X_pred, which_class = 1L, interactions = TRUE)
-#   shp2 <- shapviz(fit, X_pred = X_pred, which_class = 2L, interactions = TRUE)
-#   expect_equal(mshp, c(Class_1 = shp1, Class_2 = shp2, Class_3 = shp3))
-#   expect_equal(mshp, mshapviz(list(Class_1 = shp1, Class_2 = shp2, Class_3 = shp3)))
-# })
-#
-# test_that("combining non-shapviz objects fails", {
-#   expect_error(c(shp3, 1))
-#   expect_error(mshapviz(1, 2))
-# })
-#
+test_that("shapviz objects with interactions can be rowbinded", {
+  expect_equal(dim(rbind(shp_inter, shp_inter)), dim(shp_inter) * (2:1))
+  expect_error(rbind(shp_inter, shp))
+})
+
+# Check on mshapviz
+test_that("combining non-shapviz objects fails", {
+  expect_error(c(shp, 1))
+  expect_error(mshapviz(list(1, 2)))
+})
+
+test_that("combining incompatible shapviz objects fails", {
+  shp2 <- shp[, "x"]
+  expect_error(mshapviz(list(shp, shp2)))
+  expect_error(c(shp, shp2))
+})
+
+# Multiclass with XGBoost
+X_pred <- data.matrix(iris[, -5L])
+dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 5L]) - 1L, nthread = 1)
+fit <- xgboost::xgb.train(
+  params = list(nthread = 1L),
+  data = dtrain,
+  nrounds = 1L,
+  objective="multi:softprob",
+  num_class = 3L
+)
+shp3 <- shapviz(fit, X_pred = X_pred, which_class = 3L, interactions = TRUE)
+mshp <- shapviz(fit, X_pred = X_pred, interactions = TRUE)
+
+test_that("is.shapviz() and is.mshapviz() functions work", {
+  expect_true(is.shapviz(shp3))
+  expect_true(is.mshapviz(mshp))
+  expect_false(is.shapviz(mshp))
+  expect_false(is.mshapviz(shp3))
+})
+
+test_that("shapviz on class 3 equals mshapviz[[3]] for classification", {
+  expect_equal(mshp[[3L]], shp3)
+})
+
+test_that("combining shapviz on classes 1, 2, 3 equal mshapviz", {
+  shp1 <- shapviz(fit, X_pred = X_pred, which_class = 1L, interactions = TRUE)
+  shp2 <- shapviz(fit, X_pred = X_pred, which_class = 2L, interactions = TRUE)
+  expect_equal(mshp, c(Class_1 = shp1, Class_2 = shp2, Class_3 = shp3))
+  expect_equal(mshp, mshapviz(list(Class_1 = shp1, Class_2 = shp2, Class_3 = shp3)))
+})
+
